# Llama

Stop prompt tuning. Create your own Generative AI.

## Installation

```sh
pip install lamini
```

## Setup your keys

Go to [https://app.lamini.ai/account](https://app.lamini.ai/account) and log in to get your API key and purchase credits.

Create `~/.powerml/configure_llama.yaml` and put a key in it.

```sh
production:
    key: "<YOUR-KEY-HERE>"
```

# Documentation

Package Documentation here: [https://lamini-ai.github.io/](https://lamini-ai.github.io/)

